Coverage report

File | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
src/optwps/__init__.py | 8 | 0 | 0 | 0 | 0 | 100%
src/optwps/optwps.py | 147 | 29 | 0 | 56 | 8 | 81%
src/optwps/utils.py | 21 | 2 | 0 | 6 | 1 | 89%
tests/__init__.py | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_optwps.py | 200 | 9 | 0 | 52 | 11 | 92%
Total | 376 | 40 | 0 | 114 | 20 | 87%

No items found using the specified filter.